<?php
/**
 * @package Browser Blocker
 * @author Randall Hinton
 * @version 0.1
 */
/*
Plugin Name: Browser Blocker
Plugin URI: http://www.macnative.com/development/browser-blocker
Description: Are you tired of always having to modify perfectly good working code to allow users on inferior browser to view your website. Well Waste Time No More!!! Browser Blocker allows you to control which browser get to visit your website, and which ones get to go sit in time out.
Author: Randall Hinton
Version: 0.1
Author URI: http://www.macnative.com/
*/

register_activation_hook( __FILE__, 'BrowserBlocker_Activate' );

/**
 * Activate Plugin and set default settings
 *
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_Activate() {
		BrowserBlocker_DefaultSettings();
		BrowserBlocker_Add_Option_Menu();
}

if ( is_admin() ) {
	add_action('admin_menu', 'BrowserBlocker_Add_Option_Menu');
	add_action('admin_menu', 'BrowserBlocker_DefaultSettings');
}


/**
 * Adds the plugin's default settings
 *
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_DefaultSettings() {
	if( !get_option('Browser_Blocker_Enabled') ) {
		add_option('Browser_Blocker_Enabled', '0');
	}
	if( !get_option('Browser_Blocker_Credit') ) {
		add_option('Browser_Blocker_Credit', '1');
	}
	if( !get_option('Browser_Blocker_Title') ) {
		add_option('Browser_Blocker_Title', '');
	}
	if( !get_option('Browser_Blocker_Msg') ) {
		add_option('Browser_Blocker_Msg', '');
	}
	if( !get_option('Browser_Blocker_Splash_Img') ) {
		add_option('Browser_Blocker_Splash_Img', '');
	}
	if( !get_option('Browser_Blocker_Blocked') ) {
		add_option('Browser_Blocker_Blocked', '');
	}

}

/**
 * Gets options string from the DB and converts it into an array
 *
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_GetBlocked()
{
	$blocked = array();
	$blocked["browser"] = array();
	$blocked["direction"] = array();
	$blocked["version"] = array();
	$suboptions = explode("~",get_option('Browser_Blocker_Blocked'));
	for($x=0; $x < count($suboptions); $x++){
		$temp = explode(":",$suboptions[$x]);
		$parts = explode("_",$temp[0]);
		switch ($parts[0]){
		case "browser":
			$blocked["browser"][$parts[1]] = $temp[1];
			break;
		case "direction":
			$blocked["direction"][$parts[1]] = $temp[1];
			break;
		case "version":
			$blocked["version"][$parts[1]] = $temp[1];
			break;	
		}
	}
	return $blocked;
}

/**
 * Return Select Form Element
 *
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_Make_Select($x = "", $fields, $class="", $id="select", $name="select") {
	echo '<select name="'.$name.'" id="'.$id.'" class="'.$class.'">';
		foreach ($fields as $shown => $value) {
			if($x == $value){
				echo '<option value="'.$value.'" selected />'.$shown.'</option>';
			}else{
				echo '<option value="'.$value.'" />'.$shown.'</option>';
			}
		}
	echo '</select>';
}

/**
 * Adds the plugin's options page
 * 
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_Add_Option_Menu() {
		add_submenu_page('options-general.php', 'Browser Blocker', 'Browser Blocker', 8, __FILE__, 'BrowserBlocker_Options_Page');
}

/**
 * Return Admin Page CSS
 *
 * @since 0.1
 * @author randy@kgaps.com
 */
function BB_STYLE() {
	$siteurl = get_bloginfo('wpurl');
	$img_url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/images/';
?>
<style type="text/css">
#icon-bb {
	background: transparent url('<? echo get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/images/' ?>bb-32.png') no-repeat 2px 2px;
	float: left;
	height: 34px;
	margin: 7px 8px 0 0;
	width: 36px;
}

.hidden {
	display: none;
}

.visible {
	display: block;
}

.bb_disabled{
	background: #EBEBEB;
}

#bb_ids_box {
	background: #F5F5F5;
	width: 759px;
}

#bb_ids_box ul{
	margin-top: 15px;
	width: 750px;
}

#bb_ids_box li{
	padding: 5px 0px 5px 25px;
	margin-bottom: 0px;
	height: 59px;
}

#bb_ids_box li.disabled{
	background: #D5D5D5;
}

#bb_ids_box dl {
	padding-bottom: 5px;
	clear: both;
}

#bb_ids_box dt {
	float: left;
	width: 155px;
	padding: 10px 0px 0px 0px;
}

#bb_ids_box dd {
	float: left;
	width: 525px;
	padding: 5px 0px;
}

#bb_ids_box .labels {
	font-size: 12px;
	font-weight: bold;
	width: 225px;
	text-align: right;
	margin: 0px 15px 5px 0px;
}

#bb_ids_box label img {
	margin: 0px 5px -7px 0px;
}

#bb_ids_box .bb_nocheckbox {
	margin: 0px 5px -7px 27px;
}

#bb_ids_box .checkboxr{
	margin: 0px 15px 0px 0px;
}

.bb_example {
	font-size: 10px;
	font-style: italic;
	color: #999;
}

.bb_example2 {
	font-weight: bold;
	color: #888;
}

.bb_floater {
	float: left;
	margin-right: 5px;
}

.first {
	-moz-border-radius-bottomleft: 6px;
	-moz-border-radius-topleft: 6px;
	-webkit-border-bottom-left-radius: 6px;
	-webkit-border-top-left-radius: 6px;
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px;
}

.last {
	-moz-border-radius-bottomright: 6px;
	-moz-border-radius-topright: 6px;
	-webkit-border-bottom-right-radius: 6px;
	-webkit-border-top-right-radius: 6px;
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px;
}

.odd {
	background: #DDD url("<? echo $siteurl; ?>/wp-admin/images/gray-grad.png") repeat-x left top;
}

th {
	border-spacing: 0px;
	padding: 5px 10px;
}

td {
	text-align: center;
	border-spacing: 0px;
	padding: 3px 5px;
}

#bb_tabbed {
	background: #ECECEC;
	margin: 0 10px 10px 10px;
	border: 1px solid #CCC;
}

.tab {
	float: left;
	margin-left: 60px;
	padding: 5px 20px;
	font-size: 14px;
	margin-top: 10px;
}

.open {
	background: #ECECEC;
	border-top: 1px solid #CCC;
	border-right: 1px solid #CCC;
	border-left: 1px solid #CCC;
}

.closed {
	background: #DDD;
	border-top: 1px solid #AAA;
	border-right: 1px solid #AAA;
	border-left: 1px solid #AAA;
}

#bb_blocked_ver {
	width: 40px;
	color: #666;
}

</style>
<?
}

/**
 * Adds content to the plugin's options page
 *
 * @since 0.1
 * @author randall@macnative.com
 */
function BrowserBlocker_Options_Page() {
	global $wpdb; 
	$wpdb->show_errors();
	$siteurl = get_option('siteurl');
	$plugin_url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__));
	$img_url = $plugin_url . '/images/';
	
	BB_STYLE();
	
	if (isset($_POST['bb_update']) === true) {
		
		$errors=0;
		
		if($_POST['bb_update'] == "advanced"){
			
			if(!update_option('Browser_Blocker_Splash_Img', $_POST['bb_splash_img'])){
				$errors++;
			}
			
			if(!update_option('Browser_Blocker_Title', $_POST['bb_text'])){
				$errors++;
			}
			
			if(!update_option('Browser_Blocker_Msg', $_POST['bb_msg'])){
				$errors++;
			}
			
		}
		
		if(get_option('Browser_Blocker_Enabled') != $_POST['bb_enable']){
			if(!update_option('Browser_Blocker_Enabled', $_POST['bb_enable'])){
				$errors++;
			}
		}
		
		if(isset($_POST['bb_attribute'])){
			$attribute = 1;
		}else{
			$attribute = 0;
		}
		
		if(get_option('Browser_Blocker_Credit') != $attribute){
			if(!update_option('Browser_Blocker_Credit', $attribute)){
				$errors++;
			}
		}
		
		$blocked = "";
		for($x=0; $x < $_POST["bb_versions_detail"]; $x++){
			if($x > 0){ $blocked .= "~"; }
			$browser = "bb_browser_".$x;
			$direction = "bb_direction_".$x;
			$version = "bb_version_".$x;
			if(isset($_POST[$browser])){
				$blocked .= "browser_".$x.":".$_POST[$browser]."~direction_".$x.":".$_POST[$direction]."~version_".$x.":".$_POST[$version];
			}
			
		}
		//echo $blocked;
		
		if(get_option('Browser_Blocker_Blocked') != $blocked){
			if(!update_option('Browser_Blocker_Blocked', $blocked)){
				$errors++;
			}
		}
		
		if($errors == 0){
			$successmessage = "Browser Blocker Options Updated Successfully";
		}else{
			$errormessage = "An Error Occurred While Updating Browser Blocker Options";
		}
	
	}
		
	//$bb_options = BrowserBlocker_GetOptions();	
?>

<script type="text/javascript">

jQuery(document).ready(function($) {
	$(".fade").delay(4000).slideUp(1000);
	
	//add rows for new detail options
	$("#bb_add_browser").click(function(){
		
		$("#bb_versions").removeClass("hidden").addClass("visible");
			var rows = $("#bb_versions_detail").val();
			var browser = $("#bb_blocked").val();
			var direction = $("#bb_direction").val();
			var version = $("#bb_blocked_ver").val();
			var rowid = "#row" + rows;
			var new_row = "<tr id=\'row" + rows + "\'><td class='first'><input type='hidden' name='bb_browser_" + rows + "' id='bb_browser_" + rows + "' value='" + browser + "'>" + browser + "</td><td><input type='hidden' name='bb_direction_" + rows + "' id='bb_direction_" + rows + "' value='" + direction + "'>" + direction + "</td><td><input type='hidden' name='bb_version_" + rows + "' id='bb_version_" + rows + "' value='" + version + "'>" + version + "</td><td class='last removeRow'><img src='<?php echo $img_url."cross-circle.png" ?>' title='Remove Browser Version' /></td></tr>";
			$("#bb_versions").append(new_row);
			if(rows%2 != 0){
				$(rowid).addClass("odd");
				
			}
			$("#bb_versions_detail").val(++rows);
	
	});
	
	//remove rows
	$(".removeRow").live('click', function(){
		var rowid = $(this).closest("tr").attr("id");
		//alert(rowid);
		var agree = confirm('Are you sure you want to remove this detail row?\nThis action cannot be undone!');
		if(agree){
			$("#" + rowid).remove();
			$("#bb_versions_detail").val($("#bb_versions_detail").val()-1);
		}else{
			return false;
		}
	});
	
	$("#bb_reset").click(function(){
		var agree = confirm('Are you sure you want to reset the configured values to their defaults?\nThis action cannot be undone!');
		if(agree){
			$("#bb_splash_img").val("");
			$("#bb_text").val("");
			$("#bb_msg").val("");
		}else{
			return false;
		}
	});
});
</script>

	<div class="wrap">
		<div id="icon-bb"></div><h2>Browser Blocker Admin Options</h2>
		<?php
		if(isset($successmessage)){	
			echo '<div id="message" class="updated fade">
				<p>
					<strong>
						' . $successmessage . '
					</strong>
				</p>
			</div>';
		}
		
		if(isset($errormessage)){	
			echo '<div id="message" class="error">
				<p>
					<strong>
						' . $errormessage . '
					</strong>
				</p>
			</div>';
		}
		?>
		
		<input type="hidden" name="action" value="edit" />
			<div id="poststuff" class="ui-sortable">
			<div id="bb_ids_box" class="postbox if-js-open">
			<h3>Browser Blocker Admin Options</h3>
			
			<a href="?page=<?php echo $_GET["page"] ?>&whichP=simple"><div id="bb_simple" class="tab <?php if(!isset($_GET["whichP"]) || $_GET["whichP"] == "simple"){ echo "open"; }else{ echo "closed"; } ?>" >Simple Options</div></a><a href="?page=<?php echo $_GET["page"] ?>&whichP=advanced"><div id="bb_advanced" class="tab <?php if(isset($_GET["whichP"]) && $_GET["whichP"] == "advanced"){ echo "open"; }else{ echo "closed";  } ?>" >Advanced Options</div></a><div style="clear:both"></div>
			<div id="bb_tabbed">
			
			<?
			if(isset($_GET["whichP"]) && $_GET["whichP"] == "advanced"){
				require_once('advanced.php');
			}else{
				require_once('simple.php');	
			}
			?>
			
			</div>
			
			</div>
			</div>
			
		</div>
 	</div>
<?php
}

/**
 * Display Browser Splash Page
 *
 * @since 0.1
 * @author randall@macnative.com
 */
add_action('init', 'BrowserBlocker_Splash');

function BrowserBlocker_Splash() {
	$siteurl = get_option('siteurl');
	$plugin_url = $siteurl . '/wp-content/plugins/' . basename(dirname(__FILE__));
	$img_url = $plugin_url . '/images/';
	if(get_option('Browser_Blocker_Enabled') == 1){
		if(!is_admin()){
			require_once('browser.php');
			$browser = new Browser();
			$blocked = BrowserBlocker_GetBlocked();
			if( in_array($browser->getBrowser(),$blocked["browser"])){
				for($x=0; $x < count($blocked["browser"]); $x++){
					if($browser->getBrowser() == $blocked["browser"][$x]){
						switch($blocked["direction"][$x]){
							case "Equals":
								if($browser->getVersion() == $blocked["version"][$x]){
									BrowserBlocker_Display($browser);
								}
								break;
							case "Less Than":
								if($browser->getVersion() < $blocked["version"][$x]){
									BrowserBlocker_Display($browser);
								}
								break;
							case "Greater Than":
								if($browser->getVersion() > $blocked["version"][$x]){
									BrowserBlocker_Display($browser);
								}
								break;
							case "Equal Or Greater":
								if($browser->getVersion() >= $blocked["version"][$x]){
									BrowserBlocker_Display($browser);
								}
								break;
							case "Equal Or Less":
								if($browser->getVersion() <= $blocked["version"][$x]){
									BrowserBlocker_Display($browser);
								}
								break;
						}
					}
				}
				
			}
		}
	}
}

function BrowserBlocker_Display($browser) {
	
	require_once('splash.php');
	exit();
	
	/*header('Content-Type: text/html; charset=utf-8');
	echo $browser->getBrowser();
	if( ( $browser->getBrowser() == "Internet Explorer" && $browser->getVersion() >= 2 ) ) {
		echo 'You have FireFox version 2 or greater';
		exit();
	}else{
		echo "some other browser";
		exit();
	}
	echo "hello";*/
}

?>